@@ -50,6 +50,7 @@ class EdgeFunction(
         runtime: aws_cdk.aws_lambda.Runtime,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         allow_public_subnet: typing.Optional[builtins.bool] = None,
+        architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
         architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
         code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
         current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
@@ -92,7 +93,8 @@ class EdgeFunction(
         :param runtime: The runtime environment for the Lambda function that you are uploading. For valid values, see the Runtime property in the AWS Lambda Developer Guide. Use ``Runtime.FROM_IMAGE`` when when defining a function from a Docker image.
         :param allow_all_outbound: Whether to allow the Lambda to send all network traffic. If set to false, you must individually add traffic rules to allow the Lambda to connect to network targets. Default: true
         :param allow_public_subnet: Lambda Functions in a public subnet can NOT access the internet. Use this property to acknowledge this limitation and still place the function in a public subnet. Default: false
-        :param architectures: The system architectures compatible with this lambda function. Default: [Architecture.X86_64]
+        :param architecture: The system architectures compatible with this lambda function. Default: Architecture.X86_64
+        :param architectures: (deprecated) DEPRECATED. Default: [Architecture.X86_64]
         :param code_signing_config: Code signing config associated with this function. Default: - Not Sign the Code
         :param current_version_options: Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
         :param dead_letter_queue: The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
@@ -132,6 +134,7 @@ class EdgeFunction(
             runtime=runtime,
             allow_all_outbound=allow_all_outbound,
             allow_public_subnet=allow_public_subnet,
+            architecture=architecture,
             architectures=architectures,
             code_signing_config=code_signing_config,
             current_version_options=current_version_options,
@@ -667,6 +670,7 @@ class EdgeFunction(
         "retry_attempts": "retryAttempts",
         "allow_all_outbound": "allowAllOutbound",
         "allow_public_subnet": "allowPublicSubnet",
+        "architecture": "architecture",
         "architectures": "architectures",
         "code_signing_config": "codeSigningConfig",
         "current_version_options": "currentVersionOptions",
@@ -711,6 +715,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         retry_attempts: typing.Optional[jsii.Number] = None,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         allow_public_subnet: typing.Optional[builtins.bool] = None,
+        architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
         architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
         code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
         current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
@@ -752,7 +757,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
         :param allow_all_outbound: Whether to allow the Lambda to send all network traffic. If set to false, you must individually add traffic rules to allow the Lambda to connect to network targets. Default: true
         :param allow_public_subnet: Lambda Functions in a public subnet can NOT access the internet. Use this property to acknowledge this limitation and still place the function in a public subnet. Default: false
-        :param architectures: The system architectures compatible with this lambda function. Default: [Architecture.X86_64]
+        :param architecture: The system architectures compatible with this lambda function. Default: Architecture.X86_64
+        :param architectures: (deprecated) DEPRECATED. Default: [Architecture.X86_64]
         :param code_signing_config: Code signing config associated with this function. Default: - Not Sign the Code
         :param current_version_options: Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
         :param dead_letter_queue: The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
@@ -808,6 +814,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
             self._values["allow_all_outbound"] = allow_all_outbound
         if allow_public_subnet is not None:
             self._values["allow_public_subnet"] = allow_public_subnet
+        if architecture is not None:
+            self._values["architecture"] = architecture
         if architectures is not None:
             self._values["architectures"] = architectures
         if code_signing_config is not None:
@@ -934,13 +942,26 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         result = self._values.get("allow_public_subnet")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def architecture(self) -> typing.Optional[aws_cdk.aws_lambda.Architecture]:
+        '''The system architectures compatible with this lambda function.
+
+        :default: Architecture.X86_64
+        '''
+        result = self._values.get("architecture")
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Architecture], result)
+
     @builtins.property
     def architectures(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_lambda.Architecture]]:
-        '''The system architectures compatible with this lambda function.
+        '''(deprecated) DEPRECATED.
 
         :default: [Architecture.X86_64]
+
+        :deprecated: use ``architecture``
+
+        :stability: deprecated
         '''
         result = self._values.get("architectures")
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_lambda.Architecture]], result)
